2023-07-28 Version: 1.1.16
- Add DescribeDcdnKvNamespace.

2023-07-25 Version: 1.1.15
- Add DescribeDcdnL2Ips.

2023-07-24 Version: 1.1.14
- Add SetDcdnDomainCertificate.

2023-07-17 Version: 1.1.13
- Add SetDcdnDomainSSLCertificate.

2023-06-28 Version: 1.1.12
- Add DescribeDdosBpsMax.

2023-06-20 Version: 1.1.11
- Add DescribeDdosEventMax.

2023-06-08 Version: 1.1.10
- Update DeleteDcdnSpecificStagingConfig.

2023-05-26 Version: 1.1.9
- Add DescribeDcdnFullDomainsBlockIPConfig.

2023-05-22 Version: 1.1.8
- Add DescribeDcdnFullDomainsBlockIPHistory.

2023-05-19 Version: 1.1.7
- Add DescribeDcdnDomainMd5Info.

2023-04-25 Version: 1.1.6
- Add CheckDcdnDomainExist.

2023-03-24 Version: 1.1.5
- Add GetDcdnKv.

2023-03-04 Version: 1.1.4
- Update DescribeDcdnUserTags.

2023-02-25 Version: 1.1.3
- Update DescribeDcdnDomainUsageData.

2023-01-17 Version: 1.1.2
- Add DeleteDcdnKv.

2023-01-10 Version: 1.1.1
- Update DescribeDcdnWafLogs.

2022-12-27 Version: 1.1.0
- Add DescribeDcdnWafLogs.

2022-12-09 Version: 1.0.25
- Add DescribeDdosAllEventList.

2022-11-29 Version: 1.0.24
- Update DescribeDcdnDeletedDomains.

2022-11-17 Version: 1.0.23
- Update DescribeRDDomainConfig.

2022-11-17 Version: 1.0.22
- Add DescribeRDDomainConfig.

2022-10-27 Version: 1.0.21
- Update BatchAddDcdnDomain,add error code.

2022-10-13 Version: 1.0.20
- Update DeleteRoutineConfEnvs.

2022-09-28 Version: 1.0.19
- Update AddDcdnDomain.

2022-09-16 Version: 1.0.18
- Update DescribeDcdnReport.

2022-09-13 Version: 1.0.17
- Update DescribeDcdnL2Vips.

2022-09-01 Version: 1.0.16
- Add DescribeDcdnL2Vips.

2022-08-31 Version: 1.0.15
- Support STS.

2022-08-24 Version: 1.0.14
- AMP version.

2022-07-28 Version: 1.0.13
 - Delete SetDcdnConfigOfVersion.

2022-07-05 Version: 1.0.12
 - Add DescribeDcdnIpaDomainMultiUsageData.

2022-06-09 Version: 1.0.11
 - Update DescribeDcdnSLSRealtimeLogDelivery.

2022-05-26 Version: 1.0.10
 - Add SetDcdnFullDomainsBlockIP.

2022-04-28 Version: 1.0.9
- Add DescribeDcdnWafDomains.

2022-04-07 Version: 1.0.8
- Add DescribeDcdnWafService.

2022-03-31 Version: 1.0.7
- Add waf api.

2022-03-31 Version: 1.0.6
- AMP version.

2022-03-28 Version: 1.0.5
- AMP version.

2022-03-22 Version: 1.0.4
- Update PreloadDcdnObjectCaches.

2022-01-06 Version: 1.0.3
- Update ErrorCode.

2021-12-31 Version: 1.0.2
- Update ErrorCode.

2021-12-29 Version: 1.0.1
- AMP version.

2021-06-08 Version: 1.0.0
- Generated python2 2018-01-15 for dcdn.

